"""
This library will make the DOCX
creation process very easy.

# Install with 'pip install python-docx'

Some examples here:
- https://python-docx.readthedocs.io/en/latest/
- https://python-docx.readthedocs.io/en/latest/user/quickstart.html
"""
from dal_docx_creator.example import DocxExample

DocxExample.test_one()


"""
Module to hold some inspirational examples.

Tutorial here:
- https://python-docx.readthedocs.io/en/latest/
"""
from dal_docx_creator.creator import DocxCreator
from docx import Document


__all__ = [
    'DocxExample'
]

class DocxExample:
    """
    Class to wrap some example of DOCXs.
    """

    @staticmethod
    def test_one():
        document = Document()

        document.add_heading('Document Title', 0)

        p = document.add_paragraph('A plain paragraph having some ')
        p.add_run('bold').bold = True
        p.add_run(' and some ')
        p.add_run('italic.').italic = True

        document.add_heading('Heading, level 1', level=1)
        document.add_paragraph('Intense quote', style='Intense Quote')

        document.add_paragraph(
            'first item in unordered list', style='List Bullet'
        )
        document.add_paragraph(
            'first item in ordered list', style='List Number'
        )

        #document.add_picture('monty-truth.png', width=Inches(1.25))

        records = (
            (3, '101', 'Spam'),
            (7, '422', 'Eggs'),
            (4, '631', 'Spam, spam, eggs, and spam')
        )

        table = document.add_table(rows=1, cols=3)
        hdr_cells = table.rows[0].cells
        hdr_cells[0].text = 'Qty'
        hdr_cells[1].text = 'Id'
        hdr_cells[2].text = 'Desc'
        for qty, id, desc in records:
            row_cells = table.add_row().cells
            row_cells[0].text = str(qty)
            row_cells[1].text = id
            row_cells[2].text = desc

        document.add_page_break()

        DocxCreator.create(document, 'test_simple.docx')


from yta_general_utils.programming.output import Output
from yta_general_utils.file.enums import FileExtension
from yta_general_utils.programming.validator.parameter import ParameterValidator
from docx.document import Document
from typing import Union


class DocxCreator:
    """
    Class to simplify the creation of a DOCX.
    """

    @staticmethod
    def create(
        docx: Document,
        output_filename: Union[str, None] = None
    ) -> str:
        """
        Create the provided 'docx' as a file and
        return the filename with which the file
        has been stored locally.
        """
        ParameterValidator.validate_mandatory_instance_of('docx', docx, Document)

        output_filename = Output.get_filename(output_filename, FileExtension.DOCX)
        # TODO: I could return the docx bytearray instead
        # TODO: Is this actually returning a bytearray (?)
        docx_bytearray = docx.save(output_filename)

        return output_filename